pub struct MetropolisOptimizer { /* private fields */ }Expand description
Optimizer that implements the Metropolis algorithm with constant beta
Implementations
Sourceimpl MetropolisOptimizer
impl MetropolisOptimizer
Sourcepub fn new(
patience: usize,
n_trials: usize,
return_iter: usize,
beta: f64,
) -> Self
pub fn new( patience: usize, n_trials: usize, return_iter: usize, beta: f64, ) -> Self
Constructor of MetropolisOptimizer
patience: the optimizer will give up if there is no improvement of the score after this number of iterationsn_trials: number of trial solutions to generate and evaluate at each iterationreturn_iter: returns to the best solution if there is no improvement after this number of iterations.beta: inverse temperature
Sourcepub fn step<M: OptModel<ScoreType = NotNan<f64>>>(
&self,
model: &M,
initial_solution: M::SolutionType,
initial_score: M::ScoreType,
n_iter: usize,
time_limit: Duration,
callback: &mut dyn OptCallbackFn<M::SolutionType, M::ScoreType>,
) -> StepResult<M::SolutionType, M::ScoreType>
pub fn step<M: OptModel<ScoreType = NotNan<f64>>>( &self, model: &M, initial_solution: M::SolutionType, initial_score: M::ScoreType, n_iter: usize, time_limit: Duration, callback: &mut dyn OptCallbackFn<M::SolutionType, M::ScoreType>, ) -> StepResult<M::SolutionType, M::ScoreType>
Perform one optimization step